/* -*-comment-start: "//";comment-end:""-*-
 * GNU Mes --- Maxwell Equations of Software
 * Copyright © 2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 *
 * This file is part of GNU Mes.
 *
 * GNU Mes is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * GNU Mes is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <libmes.h>

#include <stdio.h>
#include <stdarg.h>

int
main ()
{
#if __GNUC__ && __x86_64__ && !POSIX
  return 0;
#endif
  int i;
  int r = sscanf ("42", "%d", &i);
  if (r != 1)
    return 1;
  if (i != 42)
    return 2;

  char c;
  r = sscanf ("foo bar", "foo%cbar", &c);
  if (r != 1)
    return 3;
  if (c != ' ')
    return 4;

  return 0;
}
